<?php
namespace FiloBlu\Storelocator\Block\PickUpInStore;

/**
 * Class ConfirmReceived
 * @package FiloBlu\Storelocator\Block\PickUpInStore
 */
class ConfirmReceived extends \Magento\Framework\View\Element\Template
{
    /**
     * @var \FiloBlu\Storelocator\Helper\Data
     */
    protected $helper;
    /**
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry;
    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $_storeManager;
    /**
     * @var \Magento\Framework\App\Request\Http
     */
    protected $request;

    /**
     * @var \Magento\Sales\Api\Data\OrderInterface
     */
    protected $_order;
    /**
     * @var \Magento\Framework\App\DeploymentConfig
     */
    protected $deploymentConfig;

    /**
     * ConfirmReceived constructor.
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \FiloBlu\Storelocator\Helper\Data $helper
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\App\Request\Http $request
     */
    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        \FiloBlu\Storelocator\Helper\Data $helper,
        \Magento\Framework\Registry $registry,
        \Magento\Sales\Api\Data\OrderInterface $order,
        \Magento\Framework\App\Request\Http $request,
        \Magento\Framework\App\DeploymentConfig $deploymentConfig
    )
    {
        parent::__construct($context);
        $this->helper = $helper;
        $this->_coreRegistry = $registry;
        $this->_storeManager = $context->getStoreManager();
        $this->_order = $order;
        $this->request = $request;
        $this->deploymentConfig = $deploymentConfig;
    }

    /**
     * @return bool
     */
    public function isAlreadyConfirmed() {
      return $this->_coreRegistry->registry("pickupinstore_order_confirm_received")->getPickupInStoreConfirmReceivedDate() != null;
    }

    /**
     * @return string
     */
    public function getBaseUrl() {
      return $this->_storeManager->getStore()->getBaseUrl();
    }

    public function getUrl($route = '' , $params = [])
    {
        $url = parent::getUrl($route , $params); // TODO: Change the autogenerated stub

        $url = str_replace($this->deploymentConfig->get('backend/frontName') . "/", '', $url);

        return $url;

    }

    /**
     * @return string
     */
    public function getParams() {
      if ($params = $this->getRequest()->getParams()) {
        $increment_id = isset($params["increment_id"]) ? $params["increment_id"] : "";
        $hash = isset($params["hash"]) ? $params["hash"] : "";
        return "increment_id=" . $increment_id . "&hash=" . $hash;
      }
      else {
        return "";
      }

    }

    /**
     * @return bool
     */
    public function getOrderStatus(){

        $order = $this->_order;
        return (!in_array($order->getStatus(),['complete','shipped']));
    }
}
